from .functions import *
from .enums import *
from .errors import *

__version__ = "1.1.1"
__all__ = [
    # Exceptions
    "MeosException",
    "MeosInternalError",
    "MeosArgumentError",
    "MeosIoError",
    "MeosInternalTypeError",
    "MeosValueOutOfRangeError",
    "MeosDivisionByZeroError",
    "MeosMemoryAllocError",
    "MeosAggregationError",
    "MeosDirectoryError",
    "MeosFileError",
    "MeosInvalidArgError",
    "MeosInvalidArgTypeError",
    "MeosInvalidArgValueError",
    "MeosMfJsonInputError",
    "MeosMfJsonOutputError",
    "MeosTextInputError",
    "MeosTextOutputError",
    "MeosWkbInputError",
    "MeosWkbOutputError",
    "MeosGeoJsonInputError",
    "MeosGeoJsonOutputError",
    # Enums
    "MeosType",
    "MeosTemporalSubtype",
    "MeosOperation",
    "InterpolationType",
    "SpatialRelation",
    # Functions
    "py_error_handler",
    "create_pointer",
    "get_address",
    "datetime_to_timestamptz",
    "timestamptz_to_datetime",
    "date_to_date_adt",
    "date_adt_to_date",
    "timedelta_to_interval",
    "interval_to_timedelta",
    "geo_to_gserialized",
    "geometry_to_gserialized",
    "geography_to_gserialized",
    "gserialized_to_shapely_point",
    "gserialized_to_shapely_geometry",
    "as_tinstant",
    "as_tsequence",
    "as_tsequenceset",
    "geo_get_srid",
    "meos_errno",
    "meos_errno_set",
    "meos_errno_restore",
    "meos_errno_reset",
    "meos_set_datestyle",
    "meos_set_intervalstyle",
    "meos_get_datestyle",
    "meos_get_intervalstyle",
    "meos_initialize",
    "meos_finalize",
    "add_date_int",
    "add_interval_interval",
    "add_timestamptz_interval",
    "bool_in",
    "bool_out",
    "cstring2text",
    "date_to_timestamptz",
    "minus_date_date",
    "minus_date_int",
    "minus_timestamptz_interval",
    "minus_timestamptz_timestamptz",
    "mult_interval_double",
    "pg_date_in",
    "pg_date_out",
    "pg_interval_cmp",
    "pg_interval_in",
    "pg_interval_make",
    "pg_interval_out",
    "pg_time_in",
    "pg_time_out",
    "pg_timestamp_in",
    "pg_timestamp_out",
    "pg_timestamptz_in",
    "pg_timestamptz_out",
    "text2cstring",
    "text_cmp",
    "text_copy",
    "text_initcap",
    "text_lower",
    "text_out",
    "text_upper",
    "textcat_text_text",
    "timestamptz_to_date",
    "geo_as_ewkb",
    "geo_as_ewkt",
    "geo_as_geojson",
    "geo_as_hexewkb",
    "geo_as_text",
    "geo_from_ewkb",
    "geo_from_geojson",
    "geo_out",
    "geo_same",
    "geography_from_hexewkb",
    "geography_from_text",
    "geometry_from_hexewkb",
    "geometry_from_text",
    "pgis_geography_in",
    "pgis_geometry_in",
    "bigintset_in",
    "bigintset_out",
    "bigintspan_in",
    "bigintspan_out",
    "bigintspanset_in",
    "bigintspanset_out",
    "dateset_in",
    "dateset_out",
    "datespan_in",
    "datespan_out",
    "datespanset_in",
    "datespanset_out",
    "floatset_in",
    "floatset_out",
    "floatspan_in",
    "floatspan_out",
    "floatspanset_in",
    "floatspanset_out",
    "geogset_in",
    "geomset_in",
    "geoset_as_ewkt",
    "geoset_as_text",
    "geoset_out",
    "intset_in",
    "intset_out",
    "intspan_in",
    "intspan_out",
    "intspanset_in",
    "intspanset_out",
    "set_as_hexwkb",
    "set_as_wkb",
    "set_from_hexwkb",
    "set_from_wkb",
    "span_as_hexwkb",
    "span_as_wkb",
    "span_from_hexwkb",
    "span_from_wkb",
    "spanset_as_hexwkb",
    "spanset_as_wkb",
    "spanset_from_hexwkb",
    "spanset_from_wkb",
    "textset_in",
    "textset_out",
    "tstzset_in",
    "tstzset_out",
    "tstzspan_in",
    "tstzspan_out",
    "tstzspanset_in",
    "tstzspanset_out",
    "bigintset_make",
    "bigintspan_make",
    "dateset_make",
    "datespan_make",
    "floatset_make",
    "floatspan_make",
    "geoset_make",
    "intset_make",
    "intspan_make",
    "set_copy",
    "span_copy",
    "spanset_copy",
    "spanset_make",
    "textset_make",
    "tstzset_make",
    "tstzspan_make",
    "bigint_to_set",
    "bigint_to_span",
    "bigint_to_spanset",
    "date_to_set",
    "date_to_span",
    "date_to_spanset",
    "dateset_to_tstzset",
    "datespan_to_tstzspan",
    "datespanset_to_tstzspanset",
    "float_to_set",
    "float_to_span",
    "float_to_spanset",
    "floatset_to_intset",
    "floatspan_to_intspan",
    "floatspanset_to_intspanset",
    "geo_to_set",
    "int_to_set",
    "int_to_span",
    "int_to_spanset",
    "intset_to_floatset",
    "intspan_to_floatspan",
    "intspanset_to_floatspanset",
    "set_to_spanset",
    "span_to_spanset",
    "text_to_set",
    "timestamptz_to_set",
    "timestamptz_to_span",
    "timestamptz_to_spanset",
    "tstzset_to_dateset",
    "tstzspan_to_datespan",
    "tstzspanset_to_datespanset",
    "bigintset_end_value",
    "bigintset_start_value",
    "bigintset_value_n",
    "bigintset_values",
    "bigintspan_lower",
    "bigintspan_upper",
    "bigintspan_width",
    "bigintspanset_lower",
    "bigintspanset_upper",
    "bigintspanset_width",
    "dateset_end_value",
    "dateset_start_value",
    "dateset_value_n",
    "dateset_values",
    "datespan_duration",
    "datespan_lower",
    "datespan_upper",
    "datespanset_date_n",
    "datespanset_dates",
    "datespanset_duration",
    "datespanset_end_date",
    "datespanset_num_dates",
    "datespanset_start_date",
    "floatset_end_value",
    "floatset_start_value",
    "floatset_value_n",
    "floatset_values",
    "floatspan_lower",
    "floatspan_upper",
    "floatspan_width",
    "floatspanset_lower",
    "floatspanset_upper",
    "floatspanset_width",
    "geoset_end_value",
    "geoset_srid",
    "geoset_start_value",
    "geoset_value_n",
    "geoset_values",
    "intset_end_value",
    "intset_start_value",
    "intset_value_n",
    "intset_values",
    "intspan_lower",
    "intspan_upper",
    "intspan_width",
    "intspanset_lower",
    "intspanset_upper",
    "intspanset_width",
    "set_hash",
    "set_hash_extended",
    "set_num_values",
    "set_to_span",
    "span_hash",
    "span_hash_extended",
    "span_lower_inc",
    "span_upper_inc",
    "spanset_end_span",
    "spanset_hash",
    "spanset_hash_extended",
    "spanset_lower_inc",
    "spanset_num_spans",
    "spanset_span",
    "spanset_span_n",
    "spanset_spans",
    "spanset_start_span",
    "spanset_upper_inc",
    "textset_end_value",
    "textset_start_value",
    "textset_value_n",
    "textset_values",
    "tstzset_end_value",
    "tstzset_start_value",
    "tstzset_value_n",
    "tstzset_values",
    "tstzspan_duration",
    "tstzspan_lower",
    "tstzspan_upper",
    "tstzspanset_duration",
    "tstzspanset_end_timestamptz",
    "tstzspanset_lower",
    "tstzspanset_num_timestamps",
    "tstzspanset_start_timestamptz",
    "tstzspanset_timestamptz_n",
    "tstzspanset_timestamps",
    "tstzspanset_upper",
    "bigintset_shift_scale",
    "bigintspan_shift_scale",
    "bigintspanset_shift_scale",
    "dateset_shift_scale",
    "datespan_shift_scale",
    "datespanset_shift_scale",
    "floatset_degrees",
    "floatset_radians",
    "floatset_round",
    "floatset_shift_scale",
    "floatspan_round",
    "floatspan_shift_scale",
    "floatspanset_round",
    "floatspanset_shift_scale",
    "geoset_round",
    "geoset_set_srid",
    "geoset_transform",
    "geoset_transform_pipeline",
    "point_transform",
    "point_transform_pipeline",
    "intset_shift_scale",
    "intspan_shift_scale",
    "intspanset_shift_scale",
    "textset_initcap",
    "textset_lower",
    "textset_upper",
    "textcat_textset_text",
    "textcat_text_textset",
    "timestamptz_tprecision",
    "tstzset_shift_scale",
    "tstzset_tprecision",
    "tstzspan_shift_scale",
    "tstzspan_tprecision",
    "tstzspanset_shift_scale",
    "tstzspanset_tprecision",
    "set_cmp",
    "set_eq",
    "set_ge",
    "set_gt",
    "set_le",
    "set_lt",
    "set_ne",
    "span_cmp",
    "span_eq",
    "span_ge",
    "span_gt",
    "span_le",
    "span_lt",
    "span_ne",
    "spanset_cmp",
    "spanset_eq",
    "spanset_ge",
    "spanset_gt",
    "spanset_le",
    "spanset_lt",
    "spanset_ne",
    "adjacent_span_bigint",
    "adjacent_span_date",
    "adjacent_span_float",
    "adjacent_span_int",
    "adjacent_span_span",
    "adjacent_span_spanset",
    "adjacent_span_timestamptz",
    "adjacent_spanset_bigint",
    "adjacent_spanset_date",
    "adjacent_spanset_float",
    "adjacent_spanset_int",
    "adjacent_spanset_timestamptz",
    "adjacent_spanset_span",
    "adjacent_spanset_spanset",
    "contained_bigint_set",
    "contained_bigint_span",
    "contained_bigint_spanset",
    "contained_date_set",
    "contained_date_span",
    "contained_date_spanset",
    "contained_float_set",
    "contained_float_span",
    "contained_float_spanset",
    "contained_geo_set",
    "contained_int_set",
    "contained_int_span",
    "contained_int_spanset",
    "contained_set_set",
    "contained_span_span",
    "contained_span_spanset",
    "contained_spanset_span",
    "contained_spanset_spanset",
    "contained_text_set",
    "contained_timestamptz_set",
    "contained_timestamptz_span",
    "contained_timestamptz_spanset",
    "contains_set_bigint",
    "contains_set_date",
    "contains_set_float",
    "contains_set_geo",
    "contains_set_int",
    "contains_set_set",
    "contains_set_text",
    "contains_set_timestamptz",
    "contains_span_bigint",
    "contains_span_date",
    "contains_span_float",
    "contains_span_int",
    "contains_span_span",
    "contains_span_spanset",
    "contains_span_timestamptz",
    "contains_spanset_bigint",
    "contains_spanset_date",
    "contains_spanset_float",
    "contains_spanset_int",
    "contains_spanset_span",
    "contains_spanset_spanset",
    "contains_spanset_timestamptz",
    "overlaps_set_set",
    "overlaps_span_span",
    "overlaps_span_spanset",
    "overlaps_spanset_span",
    "overlaps_spanset_spanset",
    "after_date_set",
    "after_date_span",
    "after_date_spanset",
    "after_set_date",
    "after_set_timestamptz",
    "after_span_date",
    "after_span_timestamptz",
    "after_spanset_date",
    "after_spanset_timestamptz",
    "after_timestamptz_set",
    "after_timestamptz_span",
    "after_timestamptz_spanset",
    "before_date_set",
    "before_date_span",
    "before_date_spanset",
    "before_set_date",
    "before_set_timestamptz",
    "before_span_date",
    "before_span_timestamptz",
    "before_spanset_date",
    "before_spanset_timestamptz",
    "before_timestamptz_set",
    "before_timestamptz_span",
    "before_timestamptz_spanset",
    "left_bigint_set",
    "left_bigint_span",
    "left_bigint_spanset",
    "left_float_set",
    "left_float_span",
    "left_float_spanset",
    "left_int_set",
    "left_int_span",
    "left_int_spanset",
    "left_set_bigint",
    "left_set_float",
    "left_set_int",
    "left_set_set",
    "left_set_text",
    "left_span_bigint",
    "left_span_float",
    "left_span_int",
    "left_span_span",
    "left_span_spanset",
    "left_spanset_bigint",
    "left_spanset_float",
    "left_spanset_int",
    "left_spanset_span",
    "left_spanset_spanset",
    "left_text_set",
    "overafter_date_set",
    "overafter_date_span",
    "overafter_date_spanset",
    "overafter_set_date",
    "overafter_set_timestamptz",
    "overafter_span_date",
    "overafter_span_timestamptz",
    "overafter_spanset_date",
    "overafter_spanset_timestamptz",
    "overafter_timestamptz_set",
    "overafter_timestamptz_span",
    "overafter_timestamptz_spanset",
    "overbefore_date_set",
    "overbefore_date_span",
    "overbefore_date_spanset",
    "overbefore_set_date",
    "overbefore_set_timestamptz",
    "overbefore_span_date",
    "overbefore_span_timestamptz",
    "overbefore_spanset_date",
    "overbefore_spanset_timestamptz",
    "overbefore_timestamptz_set",
    "overbefore_timestamptz_span",
    "overbefore_timestamptz_spanset",
    "overleft_bigint_set",
    "overleft_bigint_span",
    "overleft_bigint_spanset",
    "overleft_float_set",
    "overleft_float_span",
    "overleft_float_spanset",
    "overleft_int_set",
    "overleft_int_span",
    "overleft_int_spanset",
    "overleft_set_bigint",
    "overleft_set_float",
    "overleft_set_int",
    "overleft_set_set",
    "overleft_set_text",
    "overleft_span_bigint",
    "overleft_span_float",
    "overleft_span_int",
    "overleft_span_span",
    "overleft_span_spanset",
    "overleft_spanset_bigint",
    "overleft_spanset_float",
    "overleft_spanset_int",
    "overleft_spanset_span",
    "overleft_spanset_spanset",
    "overleft_text_set",
    "overright_bigint_set",
    "overright_bigint_span",
    "overright_bigint_spanset",
    "overright_float_set",
    "overright_float_span",
    "overright_float_spanset",
    "overright_int_set",
    "overright_int_span",
    "overright_int_spanset",
    "overright_set_bigint",
    "overright_set_float",
    "overright_set_int",
    "overright_set_set",
    "overright_set_text",
    "overright_span_bigint",
    "overright_span_float",
    "overright_span_int",
    "overright_span_span",
    "overright_span_spanset",
    "overright_spanset_bigint",
    "overright_spanset_float",
    "overright_spanset_int",
    "overright_spanset_span",
    "overright_spanset_spanset",
    "overright_text_set",
    "right_bigint_set",
    "right_bigint_span",
    "right_bigint_spanset",
    "right_float_set",
    "right_float_span",
    "right_float_spanset",
    "right_int_set",
    "right_int_span",
    "right_int_spanset",
    "right_set_bigint",
    "right_set_float",
    "right_set_int",
    "right_set_set",
    "right_set_text",
    "right_span_bigint",
    "right_span_float",
    "right_span_int",
    "right_span_span",
    "right_span_spanset",
    "right_spanset_bigint",
    "right_spanset_float",
    "right_spanset_int",
    "right_spanset_span",
    "right_spanset_spanset",
    "right_text_set",
    "intersection_bigint_set",
    "intersection_date_set",
    "intersection_float_set",
    "intersection_geo_set",
    "intersection_int_set",
    "intersection_set_bigint",
    "intersection_set_date",
    "intersection_set_float",
    "intersection_set_geo",
    "intersection_set_int",
    "intersection_set_set",
    "intersection_set_text",
    "intersection_set_timestamptz",
    "intersection_span_bigint",
    "intersection_span_date",
    "intersection_span_float",
    "intersection_span_int",
    "intersection_span_span",
    "intersection_span_spanset",
    "intersection_span_timestamptz",
    "intersection_spanset_bigint",
    "intersection_spanset_date",
    "intersection_spanset_float",
    "intersection_spanset_int",
    "intersection_spanset_span",
    "intersection_spanset_spanset",
    "intersection_spanset_timestamptz",
    "intersection_text_set",
    "intersection_timestamptz_set",
    "minus_bigint_set",
    "minus_bigint_span",
    "minus_bigint_spanset",
    "minus_date_set",
    "minus_date_span",
    "minus_date_spanset",
    "minus_float_set",
    "minus_float_span",
    "minus_float_spanset",
    "minus_geo_set",
    "minus_int_set",
    "minus_int_span",
    "minus_int_spanset",
    "minus_set_bigint",
    "minus_set_date",
    "minus_set_float",
    "minus_set_geo",
    "minus_set_int",
    "minus_set_set",
    "minus_set_text",
    "minus_set_timestamptz",
    "minus_span_bigint",
    "minus_span_date",
    "minus_span_float",
    "minus_span_int",
    "minus_span_span",
    "minus_span_spanset",
    "minus_span_timestamptz",
    "minus_spanset_bigint",
    "minus_spanset_date",
    "minus_spanset_float",
    "minus_spanset_int",
    "minus_spanset_span",
    "minus_spanset_spanset",
    "minus_spanset_timestamptz",
    "minus_text_set",
    "minus_timestamptz_set",
    "minus_timestamptz_span",
    "minus_timestamptz_spanset",
    "union_bigint_set",
    "union_bigint_span",
    "union_bigint_spanset",
    "union_date_set",
    "union_date_span",
    "union_date_spanset",
    "union_float_set",
    "union_float_span",
    "union_float_spanset",
    "union_geo_set",
    "union_int_set",
    "union_int_span",
    "union_int_spanset",
    "union_set_bigint",
    "union_set_date",
    "union_set_float",
    "union_set_geo",
    "union_set_int",
    "union_set_set",
    "union_set_text",
    "union_set_timestamptz",
    "union_span_bigint",
    "union_span_date",
    "union_span_float",
    "union_span_int",
    "union_span_span",
    "union_span_spanset",
    "union_span_timestamptz",
    "union_spanset_bigint",
    "union_spanset_date",
    "union_spanset_float",
    "union_spanset_int",
    "union_spanset_span",
    "union_spanset_spanset",
    "union_spanset_timestamptz",
    "union_text_set",
    "union_timestamptz_set",
    "union_timestamptz_span",
    "union_timestamptz_spanset",
    "distance_bigintset_bigintset",
    "distance_bigintspan_bigintspan",
    "distance_bigintspanset_bigintspan",
    "distance_bigintspanset_bigintspanset",
    "distance_dateset_dateset",
    "distance_datespan_datespan",
    "distance_datespanset_datespan",
    "distance_datespanset_datespanset",
    "distance_floatset_floatset",
    "distance_floatspan_floatspan",
    "distance_floatspanset_floatspan",
    "distance_floatspanset_floatspanset",
    "distance_intset_intset",
    "distance_intspan_intspan",
    "distance_intspanset_intspan",
    "distance_intspanset_intspanset",
    "distance_set_bigint",
    "distance_set_date",
    "distance_set_float",
    "distance_set_int",
    "distance_set_timestamptz",
    "distance_span_bigint",
    "distance_span_date",
    "distance_span_float",
    "distance_span_int",
    "distance_span_timestamptz",
    "distance_spanset_bigint",
    "distance_spanset_date",
    "distance_spanset_float",
    "distance_spanset_int",
    "distance_spanset_timestamptz",
    "distance_tstzset_tstzset",
    "distance_tstzspan_tstzspan",
    "distance_tstzspanset_tstzspan",
    "distance_tstzspanset_tstzspanset",
    "bigint_extent_transfn",
    "bigint_union_transfn",
    "date_extent_transfn",
    "date_union_transfn",
    "float_extent_transfn",
    "float_union_transfn",
    "int_extent_transfn",
    "int_union_transfn",
    "set_extent_transfn",
    "set_union_finalfn",
    "set_union_transfn",
    "span_extent_transfn",
    "span_union_transfn",
    "spanset_extent_transfn",
    "spanset_union_finalfn",
    "spanset_union_transfn",
    "text_union_transfn",
    "timestamptz_extent_transfn",
    "timestamptz_union_transfn",
    "tbox_in",
    "tbox_out",
    "tbox_from_wkb",
    "tbox_from_hexwkb",
    "stbox_from_wkb",
    "stbox_from_hexwkb",
    "tbox_as_wkb",
    "tbox_as_hexwkb",
    "stbox_as_wkb",
    "stbox_as_hexwkb",
    "stbox_in",
    "stbox_out",
    "float_tstzspan_to_tbox",
    "float_timestamptz_to_tbox",
    "geo_tstzspan_to_stbox",
    "geo_timestamptz_to_stbox",
    "int_tstzspan_to_tbox",
    "int_timestamptz_to_tbox",
    "numspan_tstzspan_to_tbox",
    "numspan_timestamptz_to_tbox",
    "stbox_copy",
    "stbox_make",
    "tbox_copy",
    "tbox_make",
    "float_to_tbox",
    "geo_to_stbox",
    "int_to_tbox",
    "set_to_tbox",
    "span_to_tbox",
    "spanset_to_tbox",
    "spatialset_to_stbox",
    "stbox_to_gbox",
    "stbox_to_box3d",
    "stbox_to_geo",
    "stbox_to_tstzspan",
    "tbox_to_intspan",
    "tbox_to_floatspan",
    "tbox_to_tstzspan",
    "timestamptz_to_stbox",
    "timestamptz_to_tbox",
    "tstzset_to_stbox",
    "tstzspan_to_stbox",
    "tstzspanset_to_stbox",
    "tnumber_to_tbox",
    "tpoint_to_stbox",
    "stbox_hast",
    "stbox_hasx",
    "stbox_hasz",
    "stbox_isgeodetic",
    "stbox_srid",
    "stbox_tmax",
    "stbox_tmax_inc",
    "stbox_tmin",
    "stbox_tmin_inc",
    "stbox_xmax",
    "stbox_xmin",
    "stbox_ymax",
    "stbox_ymin",
    "stbox_zmax",
    "stbox_zmin",
    "tbox_hast",
    "tbox_hasx",
    "tbox_tmax",
    "tbox_tmax_inc",
    "tbox_tmin",
    "tbox_tmin_inc",
    "tbox_xmax",
    "tbox_xmax_inc",
    "tbox_xmin",
    "tbox_xmin_inc",
    "tboxfloat_xmax",
    "tboxfloat_xmin",
    "tboxint_xmax",
    "tboxint_xmin",
    "stbox_expand_space",
    "stbox_expand_time",
    "stbox_get_space",
    "stbox_quad_split",
    "stbox_round",
    "stbox_set_srid",
    "stbox_shift_scale_time",
    "stbox_transform",
    "stbox_transform_pipeline",
    "tbox_expand_time",
    "tbox_expand_float",
    "tbox_expand_int",
    "tbox_round",
    "tbox_shift_scale_float",
    "tbox_shift_scale_int",
    "tbox_shift_scale_time",
    "union_tbox_tbox",
    "intersection_tbox_tbox",
    "union_stbox_stbox",
    "intersection_stbox_stbox",
    "adjacent_stbox_stbox",
    "adjacent_tbox_tbox",
    "contained_tbox_tbox",
    "contained_stbox_stbox",
    "contains_stbox_stbox",
    "contains_tbox_tbox",
    "overlaps_tbox_tbox",
    "overlaps_stbox_stbox",
    "same_tbox_tbox",
    "same_stbox_stbox",
    "left_tbox_tbox",
    "overleft_tbox_tbox",
    "right_tbox_tbox",
    "overright_tbox_tbox",
    "before_tbox_tbox",
    "overbefore_tbox_tbox",
    "after_tbox_tbox",
    "overafter_tbox_tbox",
    "left_stbox_stbox",
    "overleft_stbox_stbox",
    "right_stbox_stbox",
    "overright_stbox_stbox",
    "below_stbox_stbox",
    "overbelow_stbox_stbox",
    "above_stbox_stbox",
    "overabove_stbox_stbox",
    "front_stbox_stbox",
    "overfront_stbox_stbox",
    "back_stbox_stbox",
    "overback_stbox_stbox",
    "before_stbox_stbox",
    "overbefore_stbox_stbox",
    "after_stbox_stbox",
    "overafter_stbox_stbox",
    "tbox_eq",
    "tbox_ne",
    "tbox_cmp",
    "tbox_lt",
    "tbox_le",
    "tbox_ge",
    "tbox_gt",
    "stbox_eq",
    "stbox_ne",
    "stbox_cmp",
    "stbox_lt",
    "stbox_le",
    "stbox_ge",
    "stbox_gt",
    "tbool_in",
    "tint_in",
    "tfloat_in",
    "ttext_in",
    "tgeompoint_in",
    "tgeogpoint_in",
    "tbool_from_mfjson",
    "tint_from_mfjson",
    "tfloat_from_mfjson",
    "ttext_from_mfjson",
    "tgeompoint_from_mfjson",
    "tgeogpoint_from_mfjson",
    "temporal_from_wkb",
    "temporal_from_hexwkb",
    "tbool_out",
    "tint_out",
    "tfloat_out",
    "ttext_out",
    "tpoint_out",
    "tpoint_as_text",
    "tpoint_as_ewkt",
    "temporal_as_mfjson",
    "temporal_as_wkb",
    "temporal_as_hexwkb",
    "tbool_from_base_temp",
    "tboolinst_make",
    "tboolseq_from_base_tstzset",
    "tboolseq_from_base_tstzspan",
    "tboolseqset_from_base_tstzspanset",
    "temporal_copy",
    "tfloat_from_base_temp",
    "tfloatinst_make",
    "tfloatseq_from_base_tstzspan",
    "tfloatseq_from_base_tstzset",
    "tfloatseqset_from_base_tstzspanset",
    "tint_from_base_temp",
    "tintinst_make",
    "tintseq_from_base_tstzspan",
    "tintseq_from_base_tstzset",
    "tintseqset_from_base_tstzspanset",
    "tpoint_from_base_temp",
    "tpointinst_make",
    "tpointseq_from_base_tstzspan",
    "tpointseq_from_base_tstzset",
    "tpointseqset_from_base_tstzspanset",
    "tsequence_make",
    "tsequenceset_make",
    "tsequenceset_make_gaps",
    "ttext_from_base_temp",
    "ttextinst_make",
    "ttextseq_from_base_tstzspan",
    "ttextseq_from_base_tstzset",
    "ttextseqset_from_base_tstzspanset",
    "temporal_to_tstzspan",
    "tfloat_to_tint",
    "tint_to_tfloat",
    "tnumber_to_span",
    "tbool_end_value",
    "tbool_start_value",
    "tbool_value_at_timestamptz",
    "tbool_values",
    "temporal_duration",
    "temporal_end_instant",
    "temporal_end_sequence",
    "temporal_end_timestamptz",
    "temporal_hash",
    "temporal_instant_n",
    "temporal_instants",
    "temporal_interp",
    "temporal_max_instant",
    "temporal_min_instant",
    "temporal_num_instants",
    "temporal_num_sequences",
    "temporal_num_timestamps",
    "temporal_segments",
    "temporal_sequence_n",
    "temporal_sequences",
    "temporal_lower_inc",
    "temporal_upper_inc",
    "temporal_start_instant",
    "temporal_start_sequence",
    "temporal_start_timestamptz",
    "temporal_stops",
    "temporal_subtype",
    "temporal_time",
    "temporal_timestamptz_n",
    "temporal_timestamps",
    "tfloat_end_value",
    "tfloat_max_value",
    "tfloat_min_value",
    "tfloat_start_value",
    "tfloat_value_at_timestamptz",
    "tfloat_values",
    "tint_end_value",
    "tint_max_value",
    "tint_min_value",
    "tint_start_value",
    "tint_value_at_timestamptz",
    "tint_values",
    "tnumber_integral",
    "tnumber_twavg",
    "tnumber_valuespans",
    "tpoint_end_value",
    "tpoint_start_value",
    "tpoint_value_at_timestamptz",
    "tpoint_values",
    "ttext_end_value",
    "ttext_max_value",
    "ttext_min_value",
    "ttext_start_value",
    "ttext_value_at_timestamptz",
    "ttext_values",
    "float_degrees",
    "temporal_scale_time",
    "temporal_set_interp",
    "temporal_shift_scale_time",
    "temporal_shift_time",
    "temporal_to_tinstant",
    "temporal_to_tsequence",
    "temporal_to_tsequenceset",
    "tfloat_degrees",
    "tfloat_radians",
    "tfloat_round",
    "tfloat_scale_value",
    "tfloat_shift_scale_value",
    "tfloat_shift_value",
    "tfloatarr_round",
    "tint_scale_value",
    "tint_shift_scale_value",
    "tint_shift_value",
    "tpoint_round",
    "tpoint_transform",
    "tpoint_transform_pipeline",
    "tpoint_transform_pj",
    "lwproj_transform",
    "tpointarr_round",
    "temporal_append_tinstant",
    "temporal_append_tsequence",
    "temporal_delete_tstzspan",
    "temporal_delete_tstzspanset",
    "temporal_delete_timestamptz",
    "temporal_delete_tstzset",
    "temporal_insert",
    "temporal_merge",
    "temporal_merge_array",
    "temporal_update",
    "tbool_at_value",
    "tbool_minus_value",
    "temporal_at_max",
    "temporal_at_min",
    "temporal_at_tstzspan",
    "temporal_at_tstzspanset",
    "temporal_at_timestamptz",
    "temporal_at_tstzset",
    "temporal_at_values",
    "temporal_minus_max",
    "temporal_minus_min",
    "temporal_minus_tstzspan",
    "temporal_minus_tstzspanset",
    "temporal_minus_timestamptz",
    "temporal_minus_tstzset",
    "temporal_minus_values",
    "tfloat_at_value",
    "tfloat_minus_value",
    "tint_at_value",
    "tint_minus_value",
    "tnumber_at_span",
    "tnumber_at_spanset",
    "tnumber_at_tbox",
    "tnumber_minus_span",
    "tnumber_minus_spanset",
    "tnumber_minus_tbox",
    "tpoint_at_geom_time",
    "tpoint_at_stbox",
    "tpoint_at_value",
    "tpoint_minus_geom_time",
    "tpoint_minus_stbox",
    "tpoint_minus_value",
    "ttext_at_value",
    "ttext_minus_value",
    "temporal_cmp",
    "temporal_eq",
    "temporal_ge",
    "temporal_gt",
    "temporal_le",
    "temporal_lt",
    "temporal_ne",
    "always_eq_bool_tbool",
    "always_eq_float_tfloat",
    "always_eq_int_tint",
    "always_eq_point_tpoint",
    "always_eq_tbool_bool",
    "always_eq_temporal_temporal",
    "always_eq_text_ttext",
    "always_eq_tfloat_float",
    "always_eq_tint_int",
    "always_eq_tpoint_point",
    "always_eq_tpoint_tpoint",
    "always_eq_ttext_text",
    "always_ne_bool_tbool",
    "always_ne_float_tfloat",
    "always_ne_int_tint",
    "always_ne_point_tpoint",
    "always_ne_tbool_bool",
    "always_ne_temporal_temporal",
    "always_ne_text_ttext",
    "always_ne_tfloat_float",
    "always_ne_tint_int",
    "always_ne_tpoint_point",
    "always_ne_tpoint_tpoint",
    "always_ne_ttext_text",
    "always_ge_float_tfloat",
    "always_ge_int_tint",
    "always_ge_temporal_temporal",
    "always_ge_text_ttext",
    "always_ge_tfloat_float",
    "always_ge_tint_int",
    "always_ge_ttext_text",
    "always_gt_float_tfloat",
    "always_gt_int_tint",
    "always_gt_temporal_temporal",
    "always_gt_text_ttext",
    "always_gt_tfloat_float",
    "always_gt_tint_int",
    "always_gt_ttext_text",
    "always_le_float_tfloat",
    "always_le_int_tint",
    "always_le_temporal_temporal",
    "always_le_text_ttext",
    "always_le_tfloat_float",
    "always_le_tint_int",
    "always_le_ttext_text",
    "always_lt_float_tfloat",
    "always_lt_int_tint",
    "always_lt_temporal_temporal",
    "always_lt_text_ttext",
    "always_lt_tfloat_float",
    "always_lt_tint_int",
    "always_lt_ttext_text",
    "ever_eq_bool_tbool",
    "ever_eq_float_tfloat",
    "ever_eq_int_tint",
    "ever_eq_point_tpoint",
    "ever_eq_tbool_bool",
    "ever_eq_temporal_temporal",
    "ever_eq_text_ttext",
    "ever_eq_tfloat_float",
    "ever_eq_tint_int",
    "ever_eq_tpoint_point",
    "ever_eq_tpoint_tpoint",
    "ever_eq_ttext_text",
    "ever_ge_float_tfloat",
    "ever_ge_int_tint",
    "ever_ge_temporal_temporal",
    "ever_ge_text_ttext",
    "ever_ge_tfloat_float",
    "ever_ge_tint_int",
    "ever_ge_ttext_text",
    "ever_gt_float_tfloat",
    "ever_gt_int_tint",
    "ever_gt_temporal_temporal",
    "ever_gt_text_ttext",
    "ever_gt_tfloat_float",
    "ever_gt_tint_int",
    "ever_gt_ttext_text",
    "ever_le_float_tfloat",
    "ever_le_int_tint",
    "ever_le_temporal_temporal",
    "ever_le_text_ttext",
    "ever_le_tfloat_float",
    "ever_le_tint_int",
    "ever_le_ttext_text",
    "ever_lt_float_tfloat",
    "ever_lt_int_tint",
    "ever_lt_temporal_temporal",
    "ever_lt_text_ttext",
    "ever_lt_tfloat_float",
    "ever_lt_tint_int",
    "ever_lt_ttext_text",
    "ever_ne_bool_tbool",
    "ever_ne_float_tfloat",
    "ever_ne_int_tint",
    "ever_ne_point_tpoint",
    "ever_ne_tbool_bool",
    "ever_ne_temporal_temporal",
    "ever_ne_text_ttext",
    "ever_ne_tfloat_float",
    "ever_ne_tint_int",
    "ever_ne_tpoint_point",
    "ever_ne_tpoint_tpoint",
    "ever_ne_ttext_text",
    "teq_bool_tbool",
    "teq_float_tfloat",
    "teq_int_tint",
    "teq_point_tpoint",
    "teq_tbool_bool",
    "teq_temporal_temporal",
    "teq_text_ttext",
    "teq_tfloat_float",
    "teq_tpoint_point",
    "teq_tint_int",
    "teq_ttext_text",
    "tge_float_tfloat",
    "tge_int_tint",
    "tge_temporal_temporal",
    "tge_text_ttext",
    "tge_tfloat_float",
    "tge_tint_int",
    "tge_ttext_text",
    "tgt_float_tfloat",
    "tgt_int_tint",
    "tgt_temporal_temporal",
    "tgt_text_ttext",
    "tgt_tfloat_float",
    "tgt_tint_int",
    "tgt_ttext_text",
    "tle_float_tfloat",
    "tle_int_tint",
    "tle_temporal_temporal",
    "tle_text_ttext",
    "tle_tfloat_float",
    "tle_tint_int",
    "tle_ttext_text",
    "tlt_float_tfloat",
    "tlt_int_tint",
    "tlt_temporal_temporal",
    "tlt_text_ttext",
    "tlt_tfloat_float",
    "tlt_tint_int",
    "tlt_ttext_text",
    "tne_bool_tbool",
    "tne_float_tfloat",
    "tne_int_tint",
    "tne_point_tpoint",
    "tne_tbool_bool",
    "tne_temporal_temporal",
    "tne_text_ttext",
    "tne_tfloat_float",
    "tne_tpoint_point",
    "tne_tint_int",
    "tne_ttext_text",
    "adjacent_numspan_tnumber",
    "adjacent_stbox_tpoint",
    "adjacent_tbox_tnumber",
    "adjacent_temporal_temporal",
    "adjacent_temporal_tstzspan",
    "adjacent_tnumber_numspan",
    "adjacent_tnumber_tbox",
    "adjacent_tnumber_tnumber",
    "adjacent_tpoint_stbox",
    "adjacent_tpoint_tpoint",
    "adjacent_tstzspan_temporal",
    "contained_numspan_tnumber",
    "contained_stbox_tpoint",
    "contained_tbox_tnumber",
    "contained_temporal_temporal",
    "contained_temporal_tstzspan",
    "contained_tnumber_numspan",
    "contained_tnumber_tbox",
    "contained_tnumber_tnumber",
    "contained_tpoint_stbox",
    "contained_tpoint_tpoint",
    "contained_tstzspan_temporal",
    "contains_numspan_tnumber",
    "contains_stbox_tpoint",
    "contains_tbox_tnumber",
    "contains_temporal_tstzspan",
    "contains_temporal_temporal",
    "contains_tnumber_numspan",
    "contains_tnumber_tbox",
    "contains_tnumber_tnumber",
    "contains_tpoint_stbox",
    "contains_tpoint_tpoint",
    "contains_tstzspan_temporal",
    "overlaps_numspan_tnumber",
    "overlaps_stbox_tpoint",
    "overlaps_tbox_tnumber",
    "overlaps_temporal_temporal",
    "overlaps_temporal_tstzspan",
    "overlaps_tnumber_numspan",
    "overlaps_tnumber_tbox",
    "overlaps_tnumber_tnumber",
    "overlaps_tpoint_stbox",
    "overlaps_tpoint_tpoint",
    "overlaps_tstzspan_temporal",
    "same_numspan_tnumber",
    "same_stbox_tpoint",
    "same_tbox_tnumber",
    "same_temporal_temporal",
    "same_temporal_tstzspan",
    "same_tnumber_numspan",
    "same_tnumber_tbox",
    "same_tnumber_tnumber",
    "same_tpoint_stbox",
    "same_tpoint_tpoint",
    "same_tstzspan_temporal",
    "above_stbox_tpoint",
    "above_tpoint_stbox",
    "above_tpoint_tpoint",
    "after_stbox_tpoint",
    "after_tbox_tnumber",
    "after_temporal_tstzspan",
    "after_temporal_temporal",
    "after_tnumber_tbox",
    "after_tnumber_tnumber",
    "after_tpoint_stbox",
    "after_tpoint_tpoint",
    "after_tstzspan_temporal",
    "back_stbox_tpoint",
    "back_tpoint_stbox",
    "back_tpoint_tpoint",
    "before_stbox_tpoint",
    "before_tbox_tnumber",
    "before_temporal_tstzspan",
    "before_temporal_temporal",
    "before_tnumber_tbox",
    "before_tnumber_tnumber",
    "before_tpoint_stbox",
    "before_tpoint_tpoint",
    "before_tstzspan_temporal",
    "below_stbox_tpoint",
    "below_tpoint_stbox",
    "below_tpoint_tpoint",
    "front_stbox_tpoint",
    "front_tpoint_stbox",
    "front_tpoint_tpoint",
    "left_stbox_tpoint",
    "left_tbox_tnumber",
    "left_numspan_tnumber",
    "left_tnumber_numspan",
    "left_tnumber_tbox",
    "left_tnumber_tnumber",
    "left_tpoint_stbox",
    "left_tpoint_tpoint",
    "overabove_stbox_tpoint",
    "overabove_tpoint_stbox",
    "overabove_tpoint_tpoint",
    "overafter_stbox_tpoint",
    "overafter_tbox_tnumber",
    "overafter_temporal_tstzspan",
    "overafter_temporal_temporal",
    "overafter_tnumber_tbox",
    "overafter_tnumber_tnumber",
    "overafter_tpoint_stbox",
    "overafter_tpoint_tpoint",
    "overafter_tstzspan_temporal",
    "overback_stbox_tpoint",
    "overback_tpoint_stbox",
    "overback_tpoint_tpoint",
    "overbefore_stbox_tpoint",
    "overbefore_tbox_tnumber",
    "overbefore_temporal_tstzspan",
    "overbefore_temporal_temporal",
    "overbefore_tnumber_tbox",
    "overbefore_tnumber_tnumber",
    "overbefore_tpoint_stbox",
    "overbefore_tpoint_tpoint",
    "overbefore_tstzspan_temporal",
    "overbelow_stbox_tpoint",
    "overbelow_tpoint_stbox",
    "overbelow_tpoint_tpoint",
    "overfront_stbox_tpoint",
    "overfront_tpoint_stbox",
    "overfront_tpoint_tpoint",
    "overleft_numspan_tnumber",
    "overleft_stbox_tpoint",
    "overleft_tbox_tnumber",
    "overleft_tnumber_numspan",
    "overleft_tnumber_tbox",
    "overleft_tnumber_tnumber",
    "overleft_tpoint_stbox",
    "overleft_tpoint_tpoint",
    "overright_numspan_tnumber",
    "overright_stbox_tpoint",
    "overright_tbox_tnumber",
    "overright_tnumber_numspan",
    "overright_tnumber_tbox",
    "overright_tnumber_tnumber",
    "overright_tpoint_stbox",
    "overright_tpoint_tpoint",
    "right_numspan_tnumber",
    "right_stbox_tpoint",
    "right_tbox_tnumber",
    "right_tnumber_numspan",
    "right_tnumber_tbox",
    "right_tnumber_tnumber",
    "right_tpoint_stbox",
    "right_tpoint_tpoint",
    "tand_bool_tbool",
    "tand_tbool_bool",
    "tand_tbool_tbool",
    "tbool_when_true",
    "tnot_tbool",
    "tor_bool_tbool",
    "tor_tbool_bool",
    "tor_tbool_tbool",
    "add_float_tfloat",
    "add_int_tint",
    "add_tfloat_float",
    "add_tint_int",
    "add_tnumber_tnumber",
    "div_float_tfloat",
    "div_int_tint",
    "div_tfloat_float",
    "div_tint_int",
    "div_tnumber_tnumber",
    "mult_float_tfloat",
    "mult_int_tint",
    "mult_tfloat_float",
    "mult_tint_int",
    "mult_tnumber_tnumber",
    "sub_float_tfloat",
    "sub_int_tint",
    "sub_tfloat_float",
    "sub_tint_int",
    "sub_tnumber_tnumber",
    "tfloat_derivative",
    "tnumber_abs",
    "tnumber_angular_difference",
    "tnumber_delta_value",
    "textcat_text_ttext",
    "textcat_ttext_text",
    "textcat_ttext_ttext",
    "ttext_upper",
    "ttext_lower",
    "ttext_initcap",
    "distance_tfloat_float",
    "distance_tint_int",
    "distance_tnumber_tnumber",
    "distance_tpoint_point",
    "distance_tpoint_tpoint",
    "nad_stbox_geo",
    "nad_stbox_stbox",
    "nad_tint_int",
    "nad_tint_tbox",
    "nad_tint_tint",
    "nad_tboxint_tboxint",
    "nad_tfloat_float",
    "nad_tfloat_tfloat",
    "nad_tfloat_tbox",
    "nad_tboxfloat_tboxfloat",
    "nad_tpoint_geo",
    "nad_tpoint_stbox",
    "nad_tpoint_tpoint",
    "nai_tpoint_geo",
    "nai_tpoint_tpoint",
    "shortestline_tpoint_geo",
    "shortestline_tpoint_tpoint",
    "bearing_point_point",
    "bearing_tpoint_point",
    "bearing_tpoint_tpoint",
    "tpoint_angular_difference",
    "tpoint_azimuth",
    "tpoint_convex_hull",
    "tpoint_cumulative_length",
    "tpoint_direction",
    "tpoint_get_x",
    "tpoint_get_y",
    "tpoint_get_z",
    "tpoint_is_simple",
    "tpoint_length",
    "tpoint_speed",
    "tpoint_srid",
    "tpoint_stboxes",
    "tpoint_trajectory",
    "tpoint_twcentroid",
    "geo_expand_space",
    "geomeas_to_tpoint",
    "tgeogpoint_to_tgeompoint",
    "tgeompoint_to_tgeogpoint",
    "tpoint_AsMVTGeom",
    "tpoint_expand_space",
    "tpoint_make_simple",
    "tpoint_set_srid",
    "tpoint_tfloat_to_geomeas",
    "acontains_geo_tpoint",
    "adisjoint_tpoint_geo",
    "adisjoint_tpoint_tpoint",
    "adwithin_tpoint_geo",
    "adwithin_tpoint_tpoint",
    "aintersects_tpoint_geo",
    "aintersects_tpoint_tpoint",
    "atouches_tpoint_geo",
    "econtains_geo_tpoint",
    "edisjoint_tpoint_geo",
    "edisjoint_tpoint_tpoint",
    "edwithin_tpoint_geo",
    "edwithin_tpoint_tpoint",
    "eintersects_tpoint_geo",
    "eintersects_tpoint_tpoint",
    "etouches_tpoint_geo",
    "tcontains_geo_tpoint",
    "tdisjoint_tpoint_geo",
    "tdwithin_tpoint_geo",
    "tdwithin_tpoint_tpoint",
    "tintersects_tpoint_geo",
    "ttouches_tpoint_geo",
    "tbool_tand_transfn",
    "tbool_tor_transfn",
    "temporal_extent_transfn",
    "temporal_tagg_finalfn",
    "temporal_tcount_transfn",
    "tfloat_tmax_transfn",
    "tfloat_tmin_transfn",
    "tfloat_tsum_transfn",
    "tfloat_wmax_transfn",
    "tfloat_wmin_transfn",
    "tfloat_wsum_transfn",
    "timestamptz_tcount_transfn",
    "tint_tmax_transfn",
    "tint_tmin_transfn",
    "tint_tsum_transfn",
    "tint_wmax_transfn",
    "tint_wmin_transfn",
    "tint_wsum_transfn",
    "tnumber_extent_transfn",
    "tnumber_tavg_finalfn",
    "tnumber_tavg_transfn",
    "tnumber_wavg_transfn",
    "tpoint_extent_transfn",
    "tpoint_tcentroid_finalfn",
    "tpoint_tcentroid_transfn",
    "tstzset_tcount_transfn",
    "tstzspan_tcount_transfn",
    "tstzspanset_tcount_transfn",
    "ttext_tmax_transfn",
    "ttext_tmin_transfn",
    "temporal_simplify_dp",
    "temporal_simplify_max_dist",
    "temporal_simplify_min_dist",
    "temporal_simplify_min_tdelta",
    "temporal_tprecision",
    "temporal_tsample",
    "temporal_dyntimewarp_distance",
    "temporal_dyntimewarp_path",
    "temporal_frechet_distance",
    "temporal_frechet_path",
    "temporal_hausdorff_distance",
    "float_bucket",
    "floatspan_bucket_list",
    "int_bucket",
    "intspan_bucket_list",
    "stbox_tile",
    "stbox_tile_list",
    "temporal_time_split",
    "tfloat_value_split",
    "tfloat_value_time_split",
    "tfloatbox_tile",
    "tfloatbox_tile_list",
    "timestamptz_bucket",
    "tint_value_split",
    "tint_value_time_split",
    "tintbox_tile",
    "tintbox_tile_list",
    "tpoint_space_split",
    "tpoint_space_time_split",
    "tstzspan_bucket_list",
    "temptype_subtype",
    "temptype_subtype_all",
    "tempsubtype_name",
    "tempsubtype_from_string",
    "meosoper_name",
    "meosoper_from_string",
    "interptype_name",
    "interptype_from_string",
    "meostype_name",
    "temptype_basetype",
    "settype_basetype",
    "spantype_basetype",
    "spantype_spansettype",
    "spansettype_spantype",
    "basetype_spantype",
    "basetype_settype",
    "meos_basetype",
    "alpha_basetype",
    "tnumber_basetype",
    "alphanum_basetype",
    "geo_basetype",
    "spatial_basetype",
    "time_type",
    "set_basetype",
    "set_type",
    "numset_type",
    "ensure_numset_type",
    "timeset_type",
    "ensure_timeset_type",
    "set_spantype",
    "ensure_set_spantype",
    "alphanumset_type",
    "geoset_type",
    "ensure_geoset_type",
    "spatialset_type",
    "ensure_spatialset_type",
    "span_basetype",
    "span_canon_basetype",
    "span_type",
    "span_bbox_type",
    "numspan_basetype",
    "numspan_type",
    "ensure_numspan_type",
    "timespan_basetype",
    "timespan_type",
    "ensure_timespan_type",
    "spanset_type",
    "numspanset_type",
    "timespanset_type",
    "ensure_timespanset_type",
    "temporal_type",
    "temporal_basetype",
    "temptype_continuous",
    "basetype_byvalue",
    "basetype_varlength",
    "basetype_length",
    "talphanum_type",
    "talpha_type",
    "tnumber_type",
    "ensure_tnumber_type",
    "tnumber_basetype",
    "ensure_tnumber_basetype",
    "tnumber_settype",
    "tnumber_spantype",
    "tnumber_spansettype",
    "tspatial_type",
    "ensure_tspatial_type",
    "tspatial_basetype",
    "tgeo_type",
    "ensure_tgeo_type",
    "ensure_tnumber_tgeo_type",
    "datum_degrees",
    "datum_radians",
    "datum_hash",
    "datum_hash_extended",
    "set_in",
    "set_out",
    "span_in",
    "span_out",
    "spanset_in",
    "spanset_out",
    "set_cp",
    "set_make",
    "set_make_exp",
    "set_make_free",
    "span_cp",
    "span_make",
    "span_set",
    "spanset_cp",
    "spanset_make_exp",
    "spanset_make_free",
    "dateset_tstzset",
    "datespan_tstzspan",
    "datespanset_tstzspanset",
    "floatset_intset",
    "floatspan_intspan",
    "floatspanset_intspanset",
    "intset_floatset",
    "intspan_floatspan",
    "intspanset_floatspanset",
    "set_span",
    "set_spanset",
    "span_spanset",
    "tstzset_dateset",
    "tstzspan_datespan",
    "tstzspanset_datespanset",
    "value_set_span",
    "value_to_set",
    "value_to_span",
    "value_to_spanset",
    "numspan_width",
    "numspanset_width",
    "set_end_value",
    "set_mem_size",
    "set_set_span",
    "set_span",
    "set_start_value",
    "set_value_n",
    "set_vals",
    "set_values",
    "spanset_lower",
    "spanset_mem_size",
    "spanset_sps",
    "spanset_upper",
    "datespan_set_tstzspan",
    "floatset_deg",
    "floatset_rad",
    "floatset_rnd",
    "floatspan_rnd",
    "floatspanset_rnd",
    "floatspan_set_intspan",
    "intspan_set_floatspan",
    "numset_shift_scale",
    "numspan_shift_scale",
    "numspanset_shift_scale",
    "set_compact",
    "span_expand",
    "spanset_compact",
    "textcat_textset_text_int",
    "tstzspan_set_datespan",
    "set_cmp_int",
    "set_eq_int",
    "span_cmp_int",
    "span_eq_int",
    "spanset_cmp_int",
    "spanset_eq_int",
    "adj_span_span",
    "adjacent_span_value",
    "adjacent_spanset_value",
    "adjacent_value_spanset",
    "cont_span_span",
    "contained_value_set",
    "contained_value_span",
    "contained_value_spanset",
    "contains_set_value",
    "contains_span_value",
    "contains_spanset_value",
    "ovadj_span_span",
    "over_span_span",
    "left_set_value",
    "left_span_value",
    "left_spanset_value",
    "left_value_set",
    "left_value_span",
    "left_value_spanset",
    "lf_span_span",
    "lfnadj_span_span",
    "overleft_set_value",
    "overleft_span_value",
    "overleft_spanset_value",
    "overleft_value_set",
    "overleft_value_span",
    "overleft_value_spanset",
    "overright_set_value",
    "overright_span_value",
    "overright_spanset_value",
    "overright_value_set",
    "overright_value_span",
    "overright_value_spanset",
    "ovlf_span_span",
    "ovri_span_span",
    "ri_span_span",
    "right_value_set",
    "right_set_value",
    "right_value_span",
    "right_value_spanset",
    "right_span_value",
    "right_spanset_value",
    "bbox_union_span_span",
    "inter_span_span",
    "intersection_set_value",
    "intersection_span_value",
    "intersection_spanset_value",
    "intersection_value_set",
    "intersection_value_span",
    "intersection_value_spanset",
    "mi_span_span",
    "minus_set_value",
    "minus_span_value",
    "minus_spanset_value",
    "minus_value_set",
    "minus_value_span",
    "minus_value_spanset",
    "super_union_span_span",
    "union_set_value",
    "union_span_value",
    "union_spanset_value",
    "union_value_set",
    "union_value_span",
    "union_value_spanset",
    "dist_set_set",
    "dist_span_span",
    "distance_set_set",
    "distance_set_value",
    "distance_span_span",
    "distance_span_value",
    "distance_spanset_span",
    "distance_spanset_spanset",
    "distance_spanset_value",
    "distance_value_value",
    "spanbase_extent_transfn",
    "value_union_transfn",
    "number_tstzspan_to_tbox",
    "number_timestamptz_to_tbox",
    "stbox_cp",
    "stbox_set",
    "tbox_cp",
    "tbox_set",
    "box3d_to_stbox",
    "gbox_to_stbox",
    "float_set_tbox",
    "gbox_to_stbox",
    "geo_set_stbox",
    "geoarr_set_stbox",
    "int_set_tbox",
    "number_set_tbox",
    "number_to_tbox",
    "numset_set_tbox",
    "numspan_set_tbox",
    "numspanset_set_tbox",
    "spatialset_set_stbox",
    "stbox_set_box3d",
    "stbox_set_gbox",
    "timestamptz_set_stbox",
    "timestamptz_set_tbox",
    "tstzset_set_stbox",
    "tstzset_set_tbox",
    "tstzspan_set_stbox",
    "tstzspan_set_tbox",
    "tstzspanset_set_stbox",
    "tstzspanset_set_tbox",
    "tbox_shift_scale_value",
    "stbox_expand",
    "tbox_expand",
    "inter_stbox_stbox",
    "inter_tbox_tbox",
    "geoarr_as_text",
    "tboolinst_as_mfjson",
    "tboolinst_from_mfjson",
    "tboolinst_in",
    "tboolseq_as_mfjson",
    "tboolseq_from_mfjson",
    "tboolseq_in",
    "tboolseqset_as_mfjson",
    "tboolseqset_from_mfjson",
    "tboolseqset_in",
    "temporal_in",
    "temporal_out",
    "temparr_out",
    "tfloatinst_as_mfjson",
    "tfloatinst_from_mfjson",
    "tfloatinst_in",
    "tfloatseq_as_mfjson",
    "tfloatseq_from_mfjson",
    "tfloatseq_in",
    "tfloatseqset_as_mfjson",
    "tfloatseqset_from_mfjson",
    "tfloatseqset_in",
    "tgeogpointinst_from_mfjson",
    "tgeogpointinst_in",
    "tgeogpointseq_from_mfjson",
    "tgeogpointseq_in",
    "tgeogpointseqset_from_mfjson",
    "tgeogpointseqset_in",
    "tgeompointinst_from_mfjson",
    "tgeompointinst_in",
    "tgeompointseq_from_mfjson",
    "tgeompointseq_in",
    "tgeompointseqset_from_mfjson",
    "tgeompointseqset_in",
    "tinstant_as_mfjson",
    "tinstant_from_mfjson",
    "tinstant_in",
    "tinstant_out",
    "tintinst_as_mfjson",
    "tintinst_from_mfjson",
    "tintinst_in",
    "tintseq_as_mfjson",
    "tintseq_from_mfjson",
    "tintseq_in",
    "tintseqset_as_mfjson",
    "tintseqset_from_mfjson",
    "tintseqset_in",
    "tpointarr_as_text",
    "tpointinst_as_mfjson",
    "tpointseq_as_mfjson",
    "tpointseqset_as_mfjson",
    "tsequence_as_mfjson",
    "tsequence_from_mfjson",
    "tsequence_in",
    "tsequence_out",
    "tsequenceset_as_mfjson",
    "tsequenceset_from_mfjson",
    "tsequenceset_in",
    "tsequenceset_out",
    "ttextinst_as_mfjson",
    "ttextinst_from_mfjson",
    "ttextinst_in",
    "ttextseq_as_mfjson",
    "ttextseq_from_mfjson",
    "ttextseq_in",
    "ttextseqset_as_mfjson",
    "ttextseqset_from_mfjson",
    "ttextseqset_in",
    "temporal_from_mfjson",
    "temporal_cp",
    "temporal_from_base_temp",
    "tinstant_copy",
    "tinstant_make",
    "tinstant_make_free",
    "tpointseq_make_coords",
    "tsequence_copy",
    "tsequence_from_base_tstzset",
    "tsequence_from_base_tstzspan",
    "tsequence_make_exp",
    "tsequence_make_free",
    "tsequenceset_copy",
    "tseqsetarr_to_tseqset",
    "tsequenceset_from_base_tstzspanset",
    "tsequenceset_make_exp",
    "tsequenceset_make_free",
    "temporal_set_tstzspan",
    "tinstant_set_tstzspan",
    "tnumber_set_tbox",
    "tnumber_span",
    "tnumberinst_set_tbox",
    "tnumberseq_set_tbox",
    "tnumberseqset_set_tbox",
    "tsequence_set_tstzspan",
    "tsequenceset_set_tstzspan",
    "temporal_end_value",
    "temporal_insts",
    "temporal_max_value",
    "temporal_mem_size",
    "temporal_min_value",
    "temporal_seqs",
    "temporal_set_bbox",
    "temporal_set_tstzspan",
    "temporal_seqs",
    "temporal_vals",
    "temporal_values",
    "tinstant_hash",
    "tinstant_insts",
    "tinstant_set_bbox",
    "tinstant_time",
    "tinstant_timestamps",
    "tinstant_val",
    "tinstant_value",
    "tinstant_value_at_timestamptz",
    "tinstant_vals",
    "tnumber_set_span",
    "tnumberinst_valuespans",
    "tnumberseq_valuespans",
    "tnumberseqset_valuespans",
    "tsequence_duration",
    "tsequence_end_timestamptz",
    "tsequence_hash",
    "tsequence_insts",
    "tsequence_max_inst",
    "tsequence_max_val",
    "tsequence_min_inst",
    "tsequence_min_val",
    "tsequence_segments",
    "tsequence_seqs",
    "tsequence_set_bbox",
    "tsequence_expand_bbox",
    "tsequence_start_timestamptz",
    "tsequence_time",
    "tsequence_timestamps",
    "tsequence_value_at_timestamptz",
    "tsequence_vals",
    "tsequenceset_duration",
    "tsequenceset_end_timestamptz",
    "tsequenceset_hash",
    "tsequenceset_inst_n",
    "tsequenceset_insts",
    "tsequenceset_max_inst",
    "tsequenceset_max_val",
    "tsequenceset_min_inst",
    "tsequenceset_min_val",
    "tsequenceset_num_instants",
    "tsequenceset_num_timestamps",
    "tsequenceset_segments",
    "tsequenceset_seqs",
    "tsequenceset_set_bbox",
    "tsequenceset_start_timestamptz",
    "tsequenceset_time",
    "tsequenceset_timespan",
    "tsequenceset_timestamptz_n",
    "tsequenceset_timestamps",
    "tsequenceset_value_at_timestamptz",
    "tsequenceset_vals",
    "temporal_compact",
    "temporal_restart",
    "temporal_tsequence",
    "temporal_tsequenceset",
    "tinstant_shift_time",
    "tinstant_to_tsequence",
    "tinstant_to_tsequence_free",
    "tinstant_to_tsequenceset",
    "tnumber_shift_scale_value",
    "tnumberinst_shift_value",
    "tnumberseq_shift_scale_value",
    "tnumberseqset_shift_scale_value",
    "tsequence_compact",
    "tsequence_restart",
    "tsequence_set_interp",
    "tsequence_shift_scale_time",
    "tsequence_subseq",
    "tsequence_to_tinstant",
    "tsequence_to_tsequenceset",
    "tsequence_to_tsequenceset_free",
    "tsequence_to_tsequenceset_interp",
    "tsequenceset_compact",
    "tsequenceset_restart",
    "tsequenceset_set_interp",
    "tsequenceset_shift_scale_time",
    "tsequenceset_to_discrete",
    "tsequenceset_to_linear",
    "tsequenceset_to_step",
    "tsequenceset_to_tinstant",
    "tsequenceset_to_tsequence",
    "tinstant_merge",
    "tinstant_merge_array",
    "tsequence_append_tinstant",
    "tsequence_append_tsequence",
    "tsequence_delete_timestamptz",
    "tsequence_delete_tstzset",
    "tsequence_delete_tstzspan",
    "tsequence_delete_tstzspanset",
    "tsequence_insert",
    "tsequence_merge",
    "tsequence_merge_array",
    "tsequenceset_append_tinstant",
    "tsequenceset_append_tsequence",
    "tsequenceset_delete_timestamptz",
    "tsequenceset_delete_tstzset",
    "tsequenceset_delete_tstzspan",
    "tsequenceset_delete_tstzspanset",
    "tsequenceset_insert",
    "tsequenceset_merge",
    "tsequenceset_merge_array",
    "tspatial_set_stbox",
    "tpointinst_set_stbox",
    "tspatialseq_set_stbox",
    "tspatialseqset_set_stbox",
    "tsequence_expand_bbox",
    "tsequence_set_bbox",
    "tsequenceset_expand_bbox",
    "tsequenceset_set_bbox",
    "tdiscseq_restrict_minmax",
    "tcontseq_restrict_minmax",
    "temporal_bbox_restrict_set",
    "temporal_restrict_minmax",
    "temporal_restrict_timestamptz",
    "temporal_restrict_tstzset",
    "temporal_restrict_tstzspan",
    "temporal_restrict_tstzspanset",
    "temporal_restrict_value",
    "temporal_restrict_values",
    "temporal_value_at_timestamptz",
    "tinstant_restrict_tstzspan",
    "tinstant_restrict_tstzspanset",
    "tinstant_restrict_timestamptz",
    "tinstant_restrict_tstzset",
    "tinstant_restrict_value",
    "tinstant_restrict_values",
    "tnumber_restrict_span",
    "tnumber_restrict_spanset",
    "tnumberinst_restrict_span",
    "tnumberinst_restrict_spanset",
    "tnumberseqset_restrict_span",
    "tnumberseqset_restrict_spanset",
    "tpoint_restrict_geom_time",
    "tpoint_restrict_stbox",
    "tpointinst_restrict_geom_time",
    "tpointinst_restrict_stbox",
    "tpointseq_restrict_geom_time",
    "tpointseq_restrict_stbox",
    "tpointseqset_restrict_geom_time",
    "tpointseqset_restrict_stbox",
    "tsequence_at_timestamptz",
    "tsequence_restrict_tstzspan",
    "tsequence_restrict_tstzspanset",
    "tsequenceset_restrict_minmax",
    "tsequenceset_restrict_tstzspan",
    "tsequenceset_restrict_tstzspanset",
    "tsequenceset_restrict_timestamptz",
    "tsequenceset_restrict_tstzset",
    "tsequenceset_restrict_value",
    "tsequenceset_restrict_values",
    "tinstant_cmp",
    "tinstant_eq",
    "tsequence_cmp",
    "tsequence_eq",
    "tsequenceset_cmp",
    "tsequenceset_eq",
    "always_eq_base_temporal",
    "always_eq_temporal_base",
    "always_eq_tinstant_base",
    "always_eq_tpointinst_base",
    "always_eq_tpointseq_base",
    "always_eq_tpointseqset_base",
    "always_eq_tsequence_base",
    "always_eq_tsequenceset_base",
    "always_ne_base_temporal",
    "always_ne_temporal_base",
    "always_ne_tinstant_base",
    "always_ne_tpointinst_base",
    "always_ne_tpointseq_base",
    "always_ne_tpointseqset_base",
    "always_ne_tsequence_base",
    "always_ne_tsequenceset_base",
    "always_ge_base_temporal",
    "always_ge_temporal_base",
    "always_ge_tinstant_base",
    "always_ge_tsequence_base",
    "always_ge_tsequenceset_base",
    "always_gt_base_temporal",
    "always_gt_temporal_base",
    "always_gt_tinstant_base",
    "always_gt_tsequence_base",
    "always_gt_tsequenceset_base",
    "always_le_base_temporal",
    "always_le_temporal_base",
    "always_le_tinstant_base",
    "always_le_tsequence_base",
    "always_le_tsequenceset_base",
    "always_lt_base_temporal",
    "always_lt_temporal_base",
    "always_lt_tinstant_base",
    "always_lt_tsequence_base",
    "always_lt_tsequenceset_base",
    "ever_eq_base_temporal",
    "ever_eq_temporal_base",
    "ever_eq_tinstant_base",
    "ever_eq_tpointinst_base",
    "ever_eq_tpointseq_base",
    "ever_eq_tpointseqset_base",
    "ever_eq_tsequence_base",
    "ever_eq_tsequenceset_base",
    "ever_ne_base_temporal",
    "ever_ne_temporal_base",
    "ever_ne_tinstant_base",
    "ever_ne_tpointinst_base",
    "ever_ne_tpointseq_base",
    "ever_ne_tpointseqset_base",
    "ever_ne_tsequence_base",
    "ever_ne_tsequenceset_base",
    "ever_ge_base_temporal",
    "ever_ge_temporal_base",
    "ever_ge_tinstant_base",
    "ever_ge_tsequence_base",
    "ever_ge_tsequenceset_base",
    "ever_gt_base_temporal",
    "ever_gt_temporal_base",
    "ever_gt_tinstant_base",
    "ever_gt_tsequence_base",
    "ever_gt_tsequenceset_base",
    "ever_le_base_temporal",
    "ever_le_temporal_base",
    "ever_le_tinstant_base",
    "ever_le_tsequence_base",
    "ever_le_tsequenceset_base",
    "ever_lt_base_temporal",
    "ever_lt_temporal_base",
    "tfloatseq_derivative",
    "tfloatseqset_derivative",
    "tnumberinst_abs",
    "tnumberseq_abs",
    "tnumberseq_angular_difference",
    "tnumberseq_delta_value",
    "tnumberseqset_abs",
    "tnumberseqset_angular_difference",
    "tnumberseqset_delta_value",
    "distance_tnumber_number",
    "nad_tbox_tbox",
    "nad_tnumber_number",
    "nad_tnumber_tbox",
    "nad_tnumber_tnumber",
    "tpointinst_srid",
    "tpointseq_trajectory",
    "tpointseq_azimuth",
    "tpointseq_cumulative_length",
    "tpointseq_is_simple",
    "tpointseq_length",
    "tpointseq_speed",
    "tpointseq_srid",
    "tpointseq_stboxes",
    "tpointseqset_azimuth",
    "tpointseqset_cumulative_length",
    "tpointseqset_is_simple",
    "tpointseqset_length",
    "tpointseqset_speed",
    "tpointseqset_srid",
    "tpointseqset_stboxes",
    "tpointseqset_trajectory",
    "tpoint_get_coord",
    "tgeompointinst_tgeogpointinst",
    "tgeompointseq_tgeogpointseq",
    "tgeompointseqset_tgeogpointseqset",
    "tgeompoint_tgeogpoint",
    "tpointinst_set_srid",
    "tpointseq_make_simple",
    "tpointseq_set_srid",
    "tpointseqset_make_simple",
    "tpointseqset_set_srid",
    "tnumberseq_integral",
    "tnumberseq_twavg",
    "tnumberseqset_integral",
    "tnumberseqset_twavg",
    "tpointseq_twcentroid",
    "tpointseqset_twcentroid",
    "temporal_compact",
    "tsequence_compact",
    "tsequenceset_compact",
    "skiplist_free",
    "temporal_app_tinst_transfn",
    "temporal_app_tseq_transfn",
    "tnumber_value_split",
    "tbox_tile",
]
